@@ -660,5 +660,5 @@ class OculScholarsPortalPreservation(models.Model):
                 publisher=publisher
             )
 
-        logging.info(f'Added {output["title"]} to '
+        logging.info(f'Added {title} to '
                      f'{OculScholarsPortalPreservation.name()} data')
