@@ -126,6 +126,9 @@ def generic_lockss_import(url: str, model,
         csv_reader = DictReader(input_file)
 
         for row in csv_reader:
+            # trim the publisher field if needed
+            publisher = row['Publisher'][:254]
+
             publisher, created = \
                 Publisher.objects.get_or_create(name=row['Publisher'])
 
